<?php
// $Id: Shell.php.create.User
// Copyright (c) 2008-2023 Michael Stauber, SOLARSPEED.NET
// Copyright (c) 2008-2023 Team BlueOnyx, BLUEONYX.IT
// Copyright (c) 2001 Sun Microsystems, Inc.
// All Rights Reserved.

include_once('UIExtension.php');

class ShellExtension extends UIExtension {
    function display(&$ServerScriptHelper, &$container, $parameters) {

        $CI =& get_instance();
        $BX_SESSION = $CI->getBX_SESSION();
        $System = $CI->getSystem();

        $factory = $ServerScriptHelper->getHtmlComponentFactory("base-shell");
        $cce = $ServerScriptHelper->getCceClient();
        $i18n = new I18n("base-shell", $BX_SESSION['loginUser']['localePreference']);

        $System_SSH = $cce->get($System['OID'], 'SSH');

        $Shell_enabled_Map = 
            array(
                "0" => "none", 
                "1" => "jailed_sftp_scp_rsync", 
                "2" => "jailed_shell", 
                "3" => "full_shell"
            );

        // if configuring for virtual sites, don't show if the feature
        // is not enabled 
        $access = '1';
        if ( isset($parameters["VSITE_OID"]) ) {
            $feature = $cce->get($parameters["VSITE_OID"], "Shell");
            if ($feature["enabled"] == '0') {
                $access = '0';
            }
            elseif ($feature["enabled"] == '1') {
                unset($Shell_enabled_Map["2"]);
                unset($Shell_enabled_Map["3"]);
            }
            elseif ($feature["enabled"] == '2') {
                unset($Shell_enabled_Map["3"]);
            }
        }
        $defaults = $cce->get($parameters["CCE_SERVICES_OID"], "Shell");
        $defaultsSSH['GoogleAuthentication'] = $System_SSH['GoogleAuthentication'];

        // Sense checks:
        if (($System_SSH['GoogleAuthentication'] == '0') && ($defaults['GoogleAuthentication'] == '1')) {
            // System has 'GoogleAuthentication' OFF, so Users of this Vsite cannot have it ON:
            $defaults['GoogleAuthentication'] = '0';
        }

        if (isset($feature['GoogleAuthentication'])) {
            if (($feature['GoogleAuthentication'] == '0') && ($defaults['GoogleAuthentication'] == '1')) {
                // Vsite has 'GoogleAuthentication' OFF, so Users of this Vsite cannot have it ON:
                $defaults['GoogleAuthentication'] = '0';
            }
        }

        //
        //-- Page:
        //
    
        // assume PagedBlock because that is most likely going to be it
        $pageIds = $container->getPageIds();

        // Enable Shell Access:
        if ($access) {
            $shellEnable = $factory->getMultiChoice("Shell_enabled", array_values($Shell_enabled_Map));
            $shellEnable->setSelected($Shell_enabled_Map[$defaults['enabled']], true);
            $container->addFormField($shellEnable, $factory->getLabel("enableShell"), $pageIds[0]);
        }
        else {
            $word = $Shell_enabled_Map[$defaults['enabled']];
            $nokey_info = $i18n->getClean("[[base-shell.$word]]", false, array());
            $xxx = $factory->getTextField("Shell_enabled_Dummy", $nokey_info , 'r');
            $container->addFormField(
                $xxx,
                $factory->getLabel("enableShell"),
                $pageIds[0]
            );

            $xxx = $factory->getTextField("Shell_enabled", $defaults['enabled'] , '');
            $container->addFormField(
                $xxx,
                $factory->getLabel("enableShell"),
                $pageIds[0]
            );

        }

        // Google Authenticator enabled or not:
        $GA_access = 'rw';
        if (($System_SSH['GoogleAuthentication'] == '0') || ($feature['GoogleAuthentication'] == '0')) {
            // 'GoogleAuthentication' is disabled in the server settings or Vsite settings:
            $defaults['GoogleAuthentication'] = '0';
            $GA_access = 'r';
        }
        $GoogleAuthentication_Field = $factory->getBoolean('GoogleAuthentication', $defaults['GoogleAuthentication'], $GA_access);
        $container->addFormField(
            $GoogleAuthentication_Field,
            $factory->getLabel('GoogleAuthentication'),
            $pageIds[0]
            );
    }

    function handle(&$ServerScriptHelper, &$errors, &$cce_info, &$attributes) {

        $this->attributes = $attributes;

        if (($attributes['Shell_enabled'] != "0") && ($attributes['Shell_enabled'] != "1") && ($attributes['Shell_enabled'] != "2") && ($attributes['Shell_enabled'] != "3")) {
            if (!isset($this->attributes['Shell_enabled'])) {
                $this->attributes['Shell_enabled'] = "0";
            }
            else {
                // Reverse Map to get the numerical value for 'Shell_enabled':
                $Shell_enabled_Map_Reversed = 
                    array(
                        "none" => "0", 
                        "jailed_sftp_scp_rsync" => "1", 
                        "jailed_shell" => "2", 
                        "full_shell" => "3"
                    );

                $attributes['Shell_enabled'] = $Shell_enabled_Map_Reversed[$attributes['Shell_enabled']];
            }
        }

        $cce = $ServerScriptHelper->getCceClient();
        $cce->set($cce_info["CCE_OID"], 'Shell', array('enabled' => $attributes['Shell_enabled']));
        $errors = array_merge($errors, $cce->errors());

        $cce->set($cce_info["CCE_OID"], 'SSH', array('GoogleAuthentication' => $this->attributes['GoogleAuthentication']));
        $errors = array_merge($errors, $cce->errors());

    }
}
?>
